#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-2HtZ3hTRCVK4WidaOZ79en
key:                  pantry-0.8.3-2HtZ3hTRCVK4WidaOZ79en
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  cb599d0ceb36437d63d4ef1815f1a337
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-2HtZ3hTRCVK4WidaOZ79en
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN
    ansi-terminal-1.1-Hf6fFmjaIfCVZ3DoDW5HB base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.4-4pNHDFn1SavE9ybsxeeB1B
    casa-types-0.0.3-5LIKh1e5dM8GXuqT3aWZjs
    conduit-1.3.6.1-BJxsltXT31mLaWStW2N7GT
    conduit-extra-1.3.8-IyKWOH8Hunx4h59nOk18Zo containers-0.6.7
    crypton-1.0.5-1z1P9gki3DpXKZxddhNPM
    crypton-conduit-0.2.3-r6AAcOvYQpH7OOG1e3hnV
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.9-2Ib8lnLgDCaLmHleGe7QaZ
    generic-deriving-1.14.7-E45zydjQUReE3T5FFRTnL4
    hackage-security-0.6.3.2-1xeYlDOnVCb9CRGLWPCpl4
    hpack-0.38.0-1QT62TScJPM5dwOWsNXBdE
    http-client-0.7.19-uRvF7eEYhRDNuWEwLS8eA
    http-client-tls-0.3.6.4-2mFFKjIM8FK6v9pBPz2NDG
    http-conduit-2.3.9.1-4RT5tHgcjOIKEktllP4sj6
    http-download-0.2.1.0-JPswlmDXyH5IEe0Gc3vB31
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-HyBVnFdXLs0Dgiq4qkHmFH
    path-0.9.6-HdSXNgSoXZiI17pSkIHWvL
    path-io-1.8.2-xHKdr2qnwA9sDu8Wfq3cW
    persistent-2.14.6.0-L1qOpLKuNuS2W0ccT9TevH
    persistent-sqlite-2.13.3.0-BSBxRzOv5IE4u6Vg8J8dR5
    primitive-0.9.1.0-9K5vR1Mi21T8XGVzI2tm4J
    resourcet-1.3.0-1zDmXgfXfhGHcZ53EkSGgY
    rio-0.1.24.0-FcidF0Ma4YNv6HER3ssBf
    rio-orphans-0.1.2.0-3iH8rbJDNDu34pdCva0wXh
    rio-prettyprint-0.1.9.0-4KoeFBUBJ7UEd3yewqdWUQ
    tar-conduit-0.4.1-DFzvZWD3pqAJ1p2U2r7s2U text-2.0.2
    text-metrics-0.3.3-FGPBmpo5qec8F0jZAa41LA time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-7Q1StMrvuG9I60m4DIlvtT
    unliftio-0.2.25.1-5kFyykBV8QLAHqHdpZTooL
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi
    yaml-0.11.11.2-Au2qdn6SLCA15BHMrAh7pn
    zip-archive-0.4.3.2-LMYqDQ0oUxCT9ZieCrqlA

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

